/* Schedwi
   Copyright (C) 2007-2015 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* testfile.h -- Test the presence of a file on a agent */

#ifndef _TESTFILE_H
#define _TESTFILE_H

#include <schedwi.h>
#include <lwc_linkedlist.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int testfile OF((lwc_LL *hierarchy_list,
			int workload_date, unsigned long long int job_id,
			unsigned long long int host_id, const char *filename,
			char **out_message));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* testfile.h */

/*-----------------============== End Of File ==============-----------------*/
